@@ -27,12 +27,17 @@ def Metadocument(cls):
 class DocumentMetaclass(type):
     def __new__(cls, clsname, bases, clsdict):
         fields = []
-        class_dict = dict(clsdict)
-        new_class_dict = {**class_dict}
-        for key, value in class_dict.items():
-            if not str.startswith(key, "__") and not callable(value):
-                new_class_dict[key] = value
-                fields.append(key)
+        class_dictionaries = []
+        if bases is not None:
+            class_dictionaries = [base.__dict__ for base in bases]
+        class_dictionaries.append(dict(clsdict))
+        new_class_dict = {**dict(clsdict)}
+
+        for class_dict in class_dictionaries:
+            for key, value in class_dict.items():
+                if not str.startswith(key, "_") and not callable(value):
+                    new_class_dict[key] = value
+                    fields.append(key)
 
         new_class_dict["_fields"] = fields
 
